@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,7 +18,7 @@ AboutData::AboutData()
                  QStringLiteral(KADDRESSBOOK_VERSION),
                  i18n("The KDE Address Book Application"),
                  KAboutLicense::GPL_V2,
-                 i18n("Copyright © 2007–2021 KAddressBook authors"))
+                 i18n("Copyright © 2007–%1 KAddressBook authors", QStringLiteral("2022")))
 {
     addAuthor(i18n("Laurent Montel"), i18n("Current maintainer"), QStringLiteral("montel@kde.org"));
     addAuthor(i18n("Tobias König"), i18n("Previous maintainer"), QStringLiteral("tokoe@kde.org"));
@@ -26,6 +26,4 @@ AboutData::AboutData()
     addAuthor(i18n("David Bryant"), i18n("Documentation (2019)"), QStringLiteral("davidbryant@gvtc.com"), QStringLiteral("https://davidcbryant.net"));
 }
 
-AboutData::~AboutData()
-{
-}
+AboutData::~AboutData() = default;
